markuptools.MusicGlyph
======================

.. abjad-lineage:: abjad.tools.markuptools.MusicGlyph.MusicGlyph

.. autoclass:: abjad.tools.markuptools.MusicGlyph.MusicGlyph

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.args
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.command
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.force_quotes
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.__eq__
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.__format__
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.__hash__
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.__ne__
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.__repr__
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph.__str__

Bases
-----

- :py:class:`markuptools.MarkupCommand <abjad.tools.markuptools.MarkupCommand.MarkupCommand>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.args
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.command
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.force_quotes
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.__eq__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.__format__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.__hash__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.__ne__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.__repr__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.__str__
   :noindex:
